@@ -4,7 +4,7 @@ from typing import List
 from contextlib import contextmanager
 from uuid import UUID
 from shared_context.domain.model import AggregateRoot, Repository as BaseRepository
-from sqlalchemy import create_engine
+from sqlalchemy import create_engine, text, exc
 from sqlalchemy.orm import sessionmaker, scoped_session
 from sqlalchemy.dialects.mysql import BINARY
 from sqlalchemy.types import TypeDecorator
@@ -38,6 +38,10 @@ def session_scope(dsn: str):
         Session.remove()
 
 
+class RepositoryError(RuntimeError):
+    pass
+
+
 class Repository(BaseRepository):
     def __init__(self, aggregate: AggregateRoot, dsn: str):
         self._aggregate = aggregate
@@ -62,6 +66,15 @@ class Repository(BaseRepository):
 
         return result
 
+    def execute(self, sentence: str, **data):
+        with self.create_connection().connect() as conn:
+            try:
+                return conn.execute(text(sentence), **data)
+            except exc.SQLAlchemyError as error:
+                raise RepositoryError(str(error))
+            finally:
+                conn.close()
+
     def find_all(self, **kwargs) -> List[AggregateRoot]:
         with session_scope(self._dsn) as session:
             results = session.query(self._aggregate).filter_by(**kwargs).all()
@@ -83,35 +96,3 @@ class Orm(metaclass=abc.ABCMeta):
     @abc.abstractmethod
     def start_mappers(self) -> None:
         raise NotImplemented
-
-
-class BinaryUUID(TypeDecorator):
-    '''Optimize UUID keys. Store as 16 bit binary, retrieve as uuid.
-    inspired by:
-        http://mysqlserverteam.com/storing-uuid-values-in-mysql-tables/
-    '''
-
-    impl = BINARY(16)
-
-    def process_literal_param(self, value, dialect):
-        pass
-
-    @property
-    def python_type(self):
-        pass
-
-    def process_bind_param(self, value, dialect):
-        try:
-            return value.hex
-        except AttributeError:
-            try:
-                return UUID(value).hex
-            except TypeError:
-                # for some reason we ended up with the bytestring
-                # ¯\_(ツ)_/¯
-                # I'm not sure why you would do that,
-                # but here you go anyway.
-                return value
-
-    def process_result_value(self, value, dialect):
-        return UUID(bytes=value)
